@@ -1,13 +1,26 @@
-# file MASS/lm.gls.q
+# file MASS/R/lm.gls.R
 # copyright (C) 1994-2005 W. N. Venables and B. D. Ripley
 #
+#  This program is free software; you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation; either version 2 or 3 of the License
+#  (at your option).
+#
+#  This program is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
+#
+#  A copy of the GNU General Public License is available at
+#  http://www.r-project.org/Licenses/
+#
 lm.gls <-
     function(formula, data, W, subset, na.action, inverse = FALSE,
              method = "qr",
              model = FALSE, x = FALSE, y = FALSE, contrasts = NULL, ...)
 {
     call <- match.call()
-    m <- match.call(expand = FALSE)
+    m <- match.call(expand.dots = FALSE)
     m$W <- m$inverse <- m$method <- m$model <- m$x <-
         m$y <- m$contrasts <- m$... <- NULL
     m[[1]] <- as.name("model.frame")
