@@ -1,10 +1,23 @@
-# file MASS/lm.ridge.q
+# file MASS/R/lm.ridge.R
 # copyright (C) 1994-2006 W. N. Venables and B. D. Ripley
 #
+#  This program is free software; you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation; either version 2 or 3 of the License
+#  (at your option).
+#
+#  This program is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
+#
+#  A copy of the GNU General Public License is available at
+#  http://www.r-project.org/Licenses/
+#
 lm.ridge <- function(formula, data, subset, na.action,
     lambda = 0, model = FALSE, x = FALSE, y = FALSE, contrasts = NULL, ...)
 {
-    m <- match.call(expand = FALSE)
+    m <- match.call(expand.dots = FALSE)
     m$model <- m$x <- m$y <- m$contrasts <- m$... <- m$lambda <- NULL
     m[[1]] <- as.name("model.frame")
     m <- eval.parent(m)
